Gemeinde Adressverwaltung GUI: Pakete

Gemeinde Adressverwaltung GUI

Pakete
Hier folgen die Pakete mit einer Kurzbeschreibung (wenn verfügbar):
[Detailebene 12]

▼N Gemeinde |
C Login |
C Main |
NGemeinde_Def |
▼NGemeinde_Modelle |
C Jobs | Modelle Anwendungsübergreifend (Regelmäßige Aufgaben, Länder usw.)
C JobsSchlank |
C Gemeinde |
C Farbe |
C Gruppe |
C Anrede |
C Versandart |
C Person |
C PersonSchlank |
C Familie |
C PersonGruppe |
C PersonGruppeSchlank |
C FamilieGruppe |
C FamilieGruppeSchlank |
C GruppeAnsprechpartner |
C PersonVersandart |
C PersonVersandartSchlank |
C FamilieVersandart |
C FamilieVersandartSchlank |